/*
 * Copyright 2012, 2013 Evan Flynn
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.foobar.minesweeper;

import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.image.Image;

public class FieldCanvas extends Canvas {
  private final SelectionModel select = new SelectionModel();
  public static final int SQUAREW = 24;
  public static final int SQUAREH = 24;

  public void setSelection(int row, int column) {
    drawImage(row, column, Tiles.EXPOSED);
    select.select(row, column);
  }

  public void clearSelection() {
    drawImage(select.getRow(), select.getColumn(), Tiles.BLANK);
    select.clear();
  }

  public int scaleRow(double y) {
    return (int) (y / SQUAREH);
  }

  public int scaleColumn(double x) {
    return (int) (x / SQUAREW);
  }


  public void drawImage(int row, int column, Image image) {
    GraphicsContext gc = getGraphicsContext2D();
    gc.drawImage(image, column * SQUAREW, row * SQUAREH);
  }
}
